#
# spec file for package python-ubelt
#
# Copyright (c) 2025 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%{?sle15_python_module_pythons}
Name:           python-ubelt
Version:        1.3.7
Release:        1.1
Summary:        Python utility belt containing simple tools
License:        Apache-2.0
URL:            https://github.com/Erotemic/ubelt
Source:         https://github.com/Erotemic/ubelt/archive/refs/tags/v%{version}.tar.gz#/ubelt-%{version}-gh.tar.gz
BuildRequires:  %{python_module numpy}
BuildRequires:  %{python_module pip}
BuildRequires:  %{python_module pytest}
BuildRequires:  %{python_module requests}
BuildRequires:  %{python_module setuptools >= 41.0.1}
BuildRequires:  %{python_module wheel}
BuildRequires:  %{python_module xdoctest}
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
BuildArch:      noarch
%python_subpackages

%description
A Python utility belt containing simple tools, a stdlib like feel, and extra batteries

%prep
%autosetup -p1 -n ubelt-%{version}

%build
%pyproject_wheel

%install
%pyproject_install
%python_expand %fdupes %{buildroot}%{$python_sitelib}

%check
%pytest

%files %{python_files}
%doc README.rst
%license LICENSE
%{python_sitelib}/ubelt
%{python_sitelib}/ubelt-%{version}.dist-info

%changelog
* Mon Jan 13 2025 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- Update to 1.3.7
  * Added `requestkw` to `ub.download`.
  * Minor test issues.
  * `ub.IndexableWalker.diff` for empty inputs
  * Bug in `memoize_method` which could produce incorrect results
    if methods from different instances are assigned to variables.
  * Rare error in `test_copy_directory_cases` test due to list sorting.
  * Added module name printout to `schedule_deprecation`
  * `ub.hash_data` now supports `datatime.datetime`, `datetime.date`,
    `decimal.Decimal` objects.
- Drop no-lib2to3.patch, fixed upstream
- Use Python 3.11 on SLE-15 by default
* Sat Nov  2 2024 Steve Kowalik <steven.kowalik@suse.com>
- Add patch no-lib2to3.patch:
  * Do not attempt to use lib2to3 in a doctest.
* Mon Aug 19 2024 Dirk Müller <dmueller@suse.com>
- update to 1.3.6:
  * Add `ub.IndexableWalker.diff`
  * `ub.import_module_from_path` now correctly accepts `PathLike`
    objects.
  * `ub.modname_to_modpath` fixed in cases where editable
    installs use type annotations in their MAPPING definition.
  * Support for UNIX special permission (suid/sgid/svtx) codes in
    `Path.chmod`.
* Sat Apr  6 2024 Dirk Müller <dmueller@suse.com>
- update to 1.3.5:
  * New wrapper around `pathlib.Path.chmod` in
    `ubelt.Path.chmod`. Can now specify string codes like
    "u+x" or "+rw". Old stat logic works as it previously did.
  * Allow the argument to `ubelt.cmd` to be a `PathLike` object,
    which we will expect to be an executable.
  * `ub.modname_to_modpath` now handles cases where editable
    packages have modules where the name is different than the
    package.
  * Fixed deprecated usage of `ast.Num`
* Wed Feb 14 2024 Steve Kowalik <steven.kowalik@suse.com>
- Reflow the summary to avoid rpmlint exploding.
* Tue Dec  5 2023 Dirk Müller <dmueller@suse.com>
- Initial package (1.3.4)
